<?php

namespace Drupal\domain_custom_user\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityInterface;

/**
 * Event subscriber to handle user registration.
 */
class UserRegistrationSubscriber implements EventSubscriberInterface {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs the UserRegistrationSubscriber.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Handles the entity insert event.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The inserted entity.
   */
  public function onEntityInsert(EntityInterface $entity) {
    // Act only on user entities.
    if ($entity->getEntityTypeId() === 'user') {
      $username = $entity->getAccountName();
      $subdomain = $username . '.mysite.com';

      // Use the Entity Storage Handler to manage domain entities.
      $storage = $this->entityTypeManager->getStorage('domain');
      $existing_domain = $storage->load($subdomain);

      if (!$existing_domain) {
        $domain = $storage->create([
          'id' => $subdomain,
          'name' => ucfirst($username),
          'hostname' => $subdomain,
          'status' => 1,
        ]);
        $domain->save();
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      'entity.insert' => ['onEntityInsert'],
    ];
  }

}
