<?php

namespace Drupal\domain_custom_user\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for the Domain Custom User module.
 */
class DomainCustomUserSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['domain_custom_user.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'domain_custom_user_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('domain_custom_user.settings');

    $form['base_domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Base domain'),
      '#description' => $this->t('Enter the base domain to use for subdomains (e.g., "mysite.com").'),
      '#default_value' => $config->get('base_domain') ?? 'mysite.com',
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('domain_custom_user.settings')
      ->set('base_domain', $form_state->getValue('base_domain'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
