<?php

namespace Drupal\Tests\domain_custom_user\Functional;

use Drupal\domain\Entity\Domain;
use Drupal\Tests\BrowserTestBase;

/**
 * Functional tests for the Custom User Domain module.
 *
 * @group domain_custom_user
 */
class DomainCustomUserTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['user', 'domain', 'domain_custom_user'];

  /**
   * Tests that a domain is created when a user is registered.
   */
  public function testDomainCreationOnUserRegistration() {
    // Set up a base domain in configuration.
    $config = $this->config('domain_custom_user.settings');
    $config->set('base_domain', 'mysite.com')->save();

    // Create a new user.
    $user = $this->createUser(['name' => 'myuser']);

    // Verify that the corresponding domain is created.
    $subdomain = 'myuser.mysite.com';
    $domain = Domain::load($subdomain);
    $this->assertNotNull($domain, 'The domain was created.');
    $this->assertEquals($subdomain, $domain->id(), 'The domain ID is correct.');
    $this->assertEquals('Myuser', $domain->get('name')->value, 'The domain name is correct.');
    $this->assertTrue($domain->get('status')->value, 'The domain is active.');
  }

  /**
   * Tests that a domain is not duplicated for an existing user.
   */
  public function testNoDuplicateDomains() {
    // Set up a base domain in configuration.
    $config = $this->config('custom_user_domain.settings');
    $config->set('base_domain', 'mysite.com')->save();

    // Manually create a domain.
    $subdomain = 'myuser.mysite.com';
    $domain = Domain::create([
      'id' => $subdomain,
      'name' => 'Myuser',
      'hostname' => $subdomain,
      'status' => 1,
    ]);
    $domain->save();

    // Create a new user with the same username.
    $this->createUser(['name' => 'myuser']);

    // Ensure no duplicate domains are created.
    $domains = \Drupal::entityTypeManager()
      ->getStorage('domain')
      ->loadByProperties(['id' => $subdomain]);
    $this->assertCount(1, $domains, 'No duplicate domains were created.');
  }
}
